ChangeSet 1.1119.1.14, 2003/08/08 16:35:07-07:00, abbotti@mev.co.uk

[PATCH] USB: ftdi_sio - VID/PID for ID TECH IDT1221U USB to RS-232 adapter

This patch adds support for ID TECH's IDT1221U USB to RS-232 adapter
(intended for use and/or supplied with some of their magnetic/smart
card readers).  The VID and PID were provided by Steve Briggs on
the ftdi-usb-sio-devel list.


 drivers/usb/serial/ftdi_sio.c |    7 +++++++
 drivers/usb/serial/ftdi_sio.h |    6 ++++++
 2 files changed, 13 insertions(+)


diff -Nru a/drivers/usb/serial/ftdi_sio.c b/drivers/usb/serial/ftdi_sio.c
--- a/drivers/usb/serial/ftdi_sio.c	Fri Aug  8 17:04:36 2003
+++ b/drivers/usb/serial/ftdi_sio.c	Fri Aug  8 17:04:36 2003
@@ -17,6 +17,10 @@
  * See http://ftdi-usb-sio.sourceforge.net for upto date testing info
  *	and extra documentation
  *
+ * (05/Aug/2003) Ian Abbott
+ *      Added VID/PID for ID TECH IDT1221U USB to RS-232 adapter.
+ *      VID/PID provided by Steve Briggs.
+ *
  * (23/Jul/2003) Ian Abbott
  *      Added PIDs for CrystalFontz 547, 633, 631, 635, 640 and 640 from
  *      Wayne Wylupski.
@@ -324,6 +328,7 @@
 	{ USB_DEVICE_VER(SEALEVEL_VID, SEALEVEL_2803_6_PID, 0, 0x3ff) },
 	{ USB_DEVICE_VER(SEALEVEL_VID, SEALEVEL_2803_7_PID, 0, 0x3ff) },
 	{ USB_DEVICE_VER(SEALEVEL_VID, SEALEVEL_2803_8_PID, 0, 0x3ff) },
+	{ USB_DEVICE_VER(IDTECH_VID, IDTECH_IDT1221U_PID, 0, 0x3ff) },
 	{ }						/* Terminating entry */
 };
 
@@ -395,6 +400,7 @@
 	{ USB_DEVICE_VER(SEALEVEL_VID, SEALEVEL_2803_6_PID, 0x400, 0xffff) },
 	{ USB_DEVICE_VER(SEALEVEL_VID, SEALEVEL_2803_7_PID, 0x400, 0xffff) },
 	{ USB_DEVICE_VER(SEALEVEL_VID, SEALEVEL_2803_8_PID, 0x400, 0xffff) },
+	{ USB_DEVICE_VER(IDTECH_VID, IDTECH_IDT1221U_PID, 0x400, 0xffff) },
 	{ }						/* Terminating entry */
 };
 
@@ -479,6 +485,7 @@
 	{ USB_DEVICE(SEALEVEL_VID, SEALEVEL_2803_6_PID) },
 	{ USB_DEVICE(SEALEVEL_VID, SEALEVEL_2803_7_PID) },
 	{ USB_DEVICE(SEALEVEL_VID, SEALEVEL_2803_8_PID) },
+	{ USB_DEVICE(IDTECH_VID, IDTECH_IDT1221U_PID) },
 	{ USB_DEVICE_VER(FTDI_VID, FTDI_HE_TIRA1_PID, 0x400, 0xffff) },
 	{ USB_DEVICE(FTDI_VID, FTDI_USB_UIRT_PID) },
 	{ }						/* Terminating entry */
diff -Nru a/drivers/usb/serial/ftdi_sio.h b/drivers/usb/serial/ftdi_sio.h
--- a/drivers/usb/serial/ftdi_sio.h	Fri Aug  8 17:04:36 2003
+++ b/drivers/usb/serial/ftdi_sio.h	Fri Aug  8 17:04:36 2003
@@ -127,6 +127,12 @@
 /* http://home.earthlink.net/~jrhees/USBUIRT/index.htm */
 #define FTDI_USB_UIRT_PID	0xF850	/* Product Id */
 
+/*
+ * Definitions for ID TECH (www.idt-net.com) devices
+ */
+#define IDTECH_VID		0x0ACD	/* ID TECH Vendor ID */
+#define IDTECH_IDT1221U_PID	0x0300	/* IDT1221U USB to RS-232 adapter */
+
 /* Commands */
 #define FTDI_SIO_RESET 		0 /* Reset the port */
 #define FTDI_SIO_MODEM_CTRL 	1 /* Set the modem control register */
